#!/bin/sh
#----------------------------------------------------------------------------
# /usr/bin/setup-portfw.sh - setup portforwarding-rules
#
# Creation:     2002-11-24 fm
# Last Update:  $Id: setup-portfw.sh 55639 2018-06-04 20:17:42Z hbfl $
#
# Copyright (c) 2004-2020 the eisfair team, team(at)eisfair(dot)org
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

if [ "$1" != "doit" -a "$1" != "restore" -a "$#" -gt 0 ]
then
    echo "Please call without parameters or read the source!"
    exit 1
fi

src_file="$2"
src_now="$3"
rem_pre='/run/portfw.rem.'
remfile="${rem_pre}$src_file"

# Was this called without parameters?
if [ "$#" -eq 0 ]
then # Yes, call myself for every possible forwarding-rule
    for i in ${rem_pre}*
    do
        sh $0 restore $(echo $i | sed 's|'${rem_pre}'||')
    done
    exit 1
fi

# first remove existing rules for this $src*
if [ -f "$remfile" ]
then
    . $remfile
fi

if [ "$1" = "restore" ]
then
    src_now="$thisip"
fi

# create new remove-rules file & save ip
echo "thisip='$src_now'" > $remfile

case "$src_file" in
    static)
        grepexp='^\([0-9]\{1,3\}\.\)\{3\}[0-9]\{1,3\} '
        srcvar='$srchost'
        ;;
    *)
        grepexp="^$src_file "
        srcvar='$src_now'
        ;;
esac

grep "$grepexp" /etc/portfw.conf | \
while read srchost srcport desthost destport proto
do
    realsrc="`eval echo $srcvar`"
    echo "Setting up: From $realsrc:$srcport to $desthost:$destport ($proto)"
    echo "echo \"Removing: From $realsrc:$srcport to $desthost:$destport ($proto)\"" >> $remfile
    oldIFS="$IFS"
    IFS="-"
    set -- $srcport
    if [ "$2" = "" ] # check for portrange
    then
        if [ "$1" = "none" ] # check for no port
        then
            /usr/sbin/iptables -t nat -A PREROUTING -p $proto -d $realsrc -j DNAT --to $desthost
            echo "/usr/sbin/iptables -t nat -D PREROUTING -p $proto -d $realsrc -j DNAT --to $desthost" >> $remfile
        else
            /usr/sbin/iptables -t nat -A PREROUTING -p $proto -d $realsrc --dport $srcport -j DNAT --to $desthost:$destport
            echo "/usr/sbin/iptables -t nat -D PREROUTING -p $proto -d $realsrc --dport $srcport -j DNAT --to $desthost:$destport" >> $remfile
        fi
    else
        /usr/sbin/iptables -t nat -A PREROUTING -p $proto -d $realsrc --dport $1:$2 -j DNAT --to $desthost
        echo "/usr/sbin/iptables -t nat -D PREROUTING -p $proto -d $realsrc --dport $1:$2 -j DNAT --to $desthost" >> $remfile
    fi
    IFS="$oldIFS"
done

