#!/bin/sh
#----------------------------------------------------------------------------
# /var/install/config.d/dsl-update.sh - paramater update script
#
# Creation   :  2010-10-06 hbfl
# Last update:  $Id: dsl-update.sh 77708 2020-05-28 16:26:28Z hbfl $
#
# Copyright (c) 2010-2020 Holger Bruenjes, holgerbruenjes(at)gmx(dot)net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# set package name
package_name=dsl

# include configlib for using printvar
. /var/install/include/configlib

VERSION=3.0.0

# ---------------------------------------------------------------------------
# Set the default values for configuration
# ---------------------------------------------------------------------------
get_defaults()
{
    net_device=$(find /sys/class/net -maxdepth 1 -type l ! -name 'lo' ! -name 'bond*' -printf '%f\n' | head -n1)

    START_DSL='no'

    DSL_PPPOE_NAME='DSL'
    DSL_PPPOE_USEPEERDNS='no'
    DSL_PPPOE_NET="${net_device}"
    DSL_PPPOE_NET_MACADDR=''
    DSL_PPPOE_USER='user'
    DSL_PPPOE_PASS='secret'
    DSL_PPPOE_DEBUG='no'
    DSL_PPPOE_HUP_TIMEOUT='600'
    DSL_PPPOE_CHARGEINT='60'
    DSL_PPPOE_TIMES='Mo-Su:00-24:0.0:Y'
    DSL_PPPOE_TYPE='async'
}

# ---------------------------------------------------------------------------
# read old configuration and rename old variables
# ---------------------------------------------------------------------------
rename_old_variables()
{
    # read old values
    if [ -f /etc/config.d/${package_name} ]
    then
        /var/install/bin/backup-file --quiet ${package_name}
        . /etc/config.d/${package_name}
    fi

}

# ---------------------------------------------------------------------------
# Write config and default files
# ---------------------------------------------------------------------------
make_config_file()
{
    internal_conf_file=${1}
    {
    # -----------------------------------------------------------------------
    printgpl --conf ${package_name} '2010-10-06' 'hbfl'
    # -----------------------------------------------------------------------
    echo "# DSL-VERSION ${VERSION}"

    if [ -n "${START_PPPOE}" ]
    then
        if [ "${START_DSL}" = "yes" ]
        then
            START_DSL='yes'
        fi
        if [ "${START_PPPOE}" = "no" ]
        then
            START_DSL='no'
        fi

        DSL_PPPOE_NAME="${PPPOE_NAME}"
        DSL_PPPOE_USEPEERDNS="${PPPOE_USEPEERDNS}"
        if [ -n "${PPPOE_ETH}" ]
        then
            PPPOE_NET="${PPPOE_ETH}"
        fi
        DSL_PPPOE_NET="${PPPOE_NET}"
        DSL_PPPOE_NET_MACADDR="${PPPOE_NET_MACADDR}"
        DSL_PPPOE_USER="${PPPOE_USER}"
        DSL_PPPOE_PASS="${PPPOE_PASS}"
        DSL_PPPOE_DEBUG="${PPPOE_DEBUG}"
        DSL_PPPOE_HUP_TIMEOUT="${PPPOE_HUP_TIMEOUT}"
        DSL_PPPOE_CHARGEINT="${PPPOE_CHARGEINT}"
        DSL_PPPOE_TIMES="${PPPOE_TIMES}"
        DSL_PPPOE_TYPE="${PPPOE_TYPE=}"
    fi


    # -----------------------------------------------------------------------
    printgroup 'DSL configuration:'
    # -----------------------------------------------------------------------
    printvar 'START_DSL'
    printcomment            'use yes or no'

    # -----------------------------------------------------------------------
    printgroup 'PPPOE configuration:'
    # -----------------------------------------------------------------------

    printvar 'DSL_PPPOE_NAME'
    printcomment            "circuit name, don't write spaces"

    printvar 'DSL_PPPOE_USEPEERDNS'
    printcomment            'use dns server of your provider: yes or no'

    printvar 'DSL_PPPOE_NET'
    printcomment            'Network card connected to ADSL modem, net1 = 2nd'

    printvar 'DSL_PPPOE_NET_MACADDR'
    printcomment            'Mac address of your ethernet card'

    printvar 'DSL_PPPOE_USER'
    printcomment            'username'

    printvar 'DSL_PPPOE_PASS'
    printcomment            'password'

    printvar 'DSL_PPPOE_DEBUG'
    printcomment            'enable pppd debugging: yes or no'

    printvar 'DSL_PPPOE_HUP_TIMEOUT'
    printcomment            'idle time after which to hangup'

    printvar 'DSL_PPPOE_CHARGEINT'
    printcomment            'value of charge interval (in seconds)'

    printvar 'DSL_PPPOE_TIMES'
    printcomment            'times/charges when LCR'

    printvar 'DSL_PPPOE_TYPE'
    printcomment            'use async|sync'

    # -----------------------------------------------------------------------
    printend
    # -----------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}

# ---------------------------------------------------------------------------
# Create the check.d file
# ---------------------------------------------------------------------------
make_check_file()
{
printgpl --check ${package_name} '2010-10-06' 'hbfl' >/etc/check.d/${package_name}
cat >>/etc/check.d/${package_name} <<EOF
# Variable               OPT_VARIABLE     VARIABLE_N   VALUE
START_DSL                -                -            YESNO

DSL_PPPOE_NAME           START_DSL        -            NOTEMPTY
DSL_PPPOE_USEPEERDNS     START_DSL        -            YESNO
DSL_PPPOE_NET            START_DSL        -            IP_NET_NAME_LOCAL_CUI
DSL_PPPOE_NET_MACADDR    START_DSL        -            EMACADDR_LOCAL_CUI
DSL_PPPOE_USER           START_DSL        -            NOTEMPTY
DSL_PPPOE_PASS           START_DSL        -            PASSWD
DSL_PPPOE_PASS           START_DSL        -            NOTEMPTY
DSL_PPPOE_DEBUG          START_DSL        -            YESNO
DSL_PPPOE_HUP_TIMEOUT    START_DSL        -            NOTEMPTY
DSL_PPPOE_CHARGEINT      START_DSL        -            NOTEMPTY
DSL_PPPOE_TIMES          START_DSL        -            NOTEMPTY
DSL_PPPOE_TYPE           START_DSL        -            DSL_PPPOE_SYNC_TYPE
EOF

   # Set rights for check.d file
   chmod 0600 /etc/check.d/${package_name}
   chown root /etc/check.d/${package_name}

printgpl --check_exp ${package_name} '2010-10-06' 'hbfl' >/etc/check.d/${package_name}.exp
cat >>/etc/check.d/${package_name}.exp <<EOF
DSL_PPPOE_SYNC_TYPE     = 'async|sync'
                        : 'Use async or sync'
EOF

    # Set rights for check.exp file
    chmod 0600 /etc/check.d/${package_name}.exp
    chown root /etc/check.d/${package_name}.exp


printgpl --check_ext ${package_name} '2017-01-01' 'hbfl'  >/etc/check.d/${package_name}.ext
cat >>/etc/check.d/${package_name}.ext <<EOF

if (! dsl_pppoe_net =~ "(RE:UDEV_DEV_NAME)")
then
    if (dsl_pppoe_net_macaddr == "")
    then
        error "DSL_PPPOE_NET_MACADDR is required, with use of 'DSL_PPPOE_NET = \${DSL_PPPOE_NET}'"
    fi
fi
EOF

    # Set rights for check.exp file
    chmod 0600 /etc/check.d/${package_name}.ext
    chown root /etc/check.d/${package_name}.ext

}

# ---------------------------------------------------------------------------
# main
# ---------------------------------------------------------------------------
main()
{
    get_defaults

    # write default config file
    make_config_file /etc/default.d/${package_name}

    # update from old version
    rename_old_variables

    # write new config file
    make_config_file /etc/config.d/${package_name}

    # write check.d file
    make_check_file

    exit 0
}

# ---------------------------------------------------------------------------
# exec main
# ---------------------------------------------------------------------------
main "${@}"

# ---------------------------------------------------------------------------
# end
#----------------------------------------------------------------------------
